circus-top man page
###################

Synopsis
--------

circus-top [options]


Description
-----------

circus-top is a *top*-like command to display the Circus daemon and
processes managed by circus.


Options
-------

:--endpoint *ENDPOINT*:
   Connection endpoint.

:--ssh *SSH*:
   SSH Server in the format ``user@host:port``.

:--process-timeout *PROCESS_TIMEOUT*:
   After this delay of inactivity, a process will be removed.

:-h, \--help:
   Show the help message and exit.

:\--version:
   Displays Circus version and exits.


See also
--------

`circus` (1), `circusctl` (1), `circusd` (1), `circusd-stats` (1), `circus-plugin` (1).

Full Documentation is available at https://circus.readthedocs.io
